==> magento-6.x-1.1.tar.gz: magento/magento_orders/templates/cart-page.tpl.php <==
<?php drupal_add_js(drupal_get_path("theme", "cigale")."/js/jquery_combobox.js");?>
<div class="custom-cont-block tunnel-block">
    <div class="fix title">Votre panier</div>
    <div class="c">
        <table border="0" cellpadding="0" cellspacing="0" align="center" width="100%">
            <?php foreach ($form['products'] as $id => $product): ?>
            <?php if (is_numeric($id)) : ?>
                <tr>
<!--                    <td class="check"><?php print drupal_render($form['products'][$id]['delete_item_'.$id.'']); ?></td>-->
                    <td class="name"><?php print drupal_render($form['products'][$id]['title']); ?></td>
                    <td class="prize"><?php print drupal_render($form['products'][$id]['amount']); ?>
                    	<span class="exp-prize"><?php print drupal_render($form['products'][$id]['original_price']); ?></span>
                    </td>
                    <td class="size"><?php print drupal_render($form['products'][$id]['product_count_'.$id.'']); ?></td>
                    <td class="to"><?php print drupal_render($form['products'][$id]['update']); ?></td>
                    <td class="full-prize"><?php print drupal_render($form['products'][$id]['subtotal']); ?></td>
                </tr>
            <?php endif; ?>
            <?php endforeach; ?>
        </table>
        <div id="change-cart">
            <?php print drupal_render($form['update']); ?>
            <?php print drupal_render($form['delete']); ?>
            <?php print drupal_render($form['clear']); ?>
        </div>
        <div class="do-info-block">
            <div class="right-column">
                <table border="0" cellpadding="0" cellspacing="0" align="right">
                    <tr>
                        <td><?php print t('Total de vos achats');?></td>
                        <td><?php print drupal_render($form['quote']['subtotal']); ?></td>
                    </tr>
                    <?php if ($form['quote']['discount_amount']) {?>
                    <tr>
                        <td><?php print t('Remise');?></td>
                        <td><?php print drupal_render($form['quote']['discount_amount']); ?></td>
                    </tr>
                    <?php }?>
                    <?php if ($form['quote']['shipping_amount']) {?>
                    <tr>
                        <td><?php print t('Livraison');?></td>
                        <td><?php print drupal_render($form['quote']['shipping_amount']); ?></td>
                    </tr>
                    <?php }?>
                    <?php if ($form['quote']['taxes']) {?>
                        <tr>
                            <td><?php print t('TVA');?></td>
                            <td><?php print drupal_render($form['quote']['taxes']); ?></td>
                        </tr>
                    <?php }?>
                    <tr class="total">
                        <td><?php print t('Total commande');?></td>
                        <td><?php print drupal_render($form['quote']['grand_total']); ?></td>
                    </tr>
                </table>
            </div>
            <div class="left-column">
                <div class="select-block">
                    <div class="t-block"></div>
                    <div class="c-block">
                        <div class="in-block">
                        <?php print drupal_render($form['address']['country_id']);?>
                        <?php print drupal_render($form['get_quote']);?>
                        <?php if ($form['address']['shipping_rates']) {
                          print drupal_render($form['address']['shipping_rates']);
                          print drupal_render($form['update_total']);                          
                        }?>
                        </div>
                    </div>
                    <div class="b-block"></div>
                </div>
            </div>
            <div class="endcol"></div>
        </div>
												
        <div class="btns">
            <div class="colr rol-img">
                <div id="process-checkout">
                    <?php print drupal_render($form['submit']); ?>
                </div>
            </div>
            <div class="col rol-img">
                <img src="<?= base_path() . drupal_get_path('theme', 'cigale') ?>/images/btns/btn_white_poursuivre_achats.gif" alt="" />
                <a href="<?php print url('catalogue');?>"><img src="<?= base_path() . drupal_get_path('theme', 'cigale') ?>/images/btns/btn_white_poursuivre_achats_act.gif" class="rol" alt="" /></a>
            </div>
            <div class="endcol"></div>
        </div>
        <?php print drupal_render($form); ?>
    </div>
    <div class="fix b"></div>
</div>

==> magento-6.x-1.3.tar.gz: magento/magento_orders/templates/cart-page.tpl.php <==
<div class="custom-cont-block tunnel-block">
    <div class="c">
        <table border="0" cellpadding="0" cellspacing="0" align="center" width="100%">
            <?php foreach ($form['products'] as $id => $product): ?>
            <?php if (is_numeric($id)) : ?>
                <tr>
                    <td class="check"><?php print drupal_render($form['products'][$id]['delete_item_'.$id.'']); ?></td>
                    <td class="name"><?php print drupal_render($form['products'][$id]['title']); ?></td>
                    <td class="prize"><?php print drupal_render($form['products'][$id]['amount']); ?>
                    	<span class="exp-prize"><?php print drupal_render($form['products'][$id]['original_price']); ?></span>
                    </td>
                    <td class="size"><?php print drupal_render($form['products'][$id]['product_count_'.$id.'']); ?></td>
                    <td class="to"><?php print drupal_render($form['products'][$id]['update']); ?></td>
                    <td class="full-prize"><?php print drupal_render($form['products'][$id]['subtotal']); ?></td>
                </tr>
            <?php endif; ?>
            <?php endforeach; ?>
        </table>
        <div id="change-cart">
            <?php print drupal_render($form['update']); ?>
            <?php print drupal_render($form['delete']); ?>
            <?php print drupal_render($form['clear']); ?>
        </div>
        <div class="do-info-block">
            <div class="right-column">
                <table border="0" cellpadding="0" cellspacing="0" align="right">
                    <tr>
                        <td><?php print t('Total purchases');?></td>
                        <td><?php print drupal_render($form['quote']['subtotal']); ?></td>
                    </tr>
                    <?php if ($form['quote']['discount_amount']) {?>
                    <tr>
                        <td><?php print t('Discount');?></td>
                        <td><?php print drupal_render($form['quote']['discount_amount']); ?></td>
                    </tr>
                    <?php }?>
                    <?php if ($form['quote']['shipping_amount']) {?>
                    <tr>
                        <td><?php print t('Delivery');?></td>
                        <td><?php print drupal_render($form['quote']['shipping_amount']); ?></td>
                    </tr>
                    <?php }?>
                    <?php if ($form['quote']['taxes']) {?>
                        <tr>
                            <td><?php print t('Taxes');?></td>
                            <td><?php print drupal_render($form['quote']['taxes']); ?></td>
                        </tr>
                    <?php }?>
                    <tr class="total">
                        <td><?php print t('Order Total');?></td>
                        <td><?php print drupal_render($form['quote']['grand_total']); ?></td>
                    </tr>
                </table>
            </div>
            <div class="left-column">
                <div class="select-block">
                    <div class="t-block"></div>
                    <div class="c-block">
                        <div class="in-block">
                        <?php print drupal_render($form['address']['country_id']);?>
                        <?php print drupal_render($form['get_quote']);?>
                        <?php if ($form['address']['shipping_rates']) {
                          print drupal_render($form['address']['shipping_rates']);
                          print drupal_render($form['update_total']);                          
                        }?>
                        </div>
                    </div>
                    <div class="b-block"></div>
                </div>
            </div>
            <div class="endcol"></div>
        </div>
												
        <div class="btns">
            <div class="colr rol-img">
                <div id="process-checkout">
                    <?php print drupal_render($form['submit']); ?>
                </div>
            </div>
            <div class="endcol"></div>
        </div>
        <?php print drupal_render($form); ?>
    </div>
    <div class="fix b"></div>
</div>
